Class: Google::Apis::DomainsV1alpha2::Registration
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1alpha2::Registration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1alpha2/classes.rb,
lib/google/apis/domains_v1alpha2/representations.rb,
lib/google/apis/domains_v1alpha2/representations.rb
Overview
The Registration resource facilitates managing and configuring domain name
registrations. There are several ways to create a new Registration resource:
To create a new Registration resource, find a suitable domain name by
calling the SearchDomains method with a query to see available domain name
options. After choosing a name, call RetrieveRegisterParameters to ensure
availability and obtain information like pricing, which is needed to build a
call to RegisterDomain. Another way to create a new Registration is to
transfer an existing domain from another registrar (Deprecated: For more
information, see Cloud Domains feature deprecation). First, go to the current
registrar to unlock the domain for transfer and retrieve the domain's transfer
authorization code. Then call RetrieveTransferParameters to confirm that the
domain is unlocked and to get values needed to build a call to TransferDomain
. Finally, you can create a new Registration by importing an existing domain
managed with Google Domains (Deprecated: For more
information, see Cloud Domains feature deprecation). First, call
RetrieveImportableDomains to list domains to which the calling user has
sufficient access. Then call ImportDomain on any domain names you want to
use with Cloud Domains.
Instance Attribute Summary collapse
-
#contact_settings ⇒ Google::Apis::DomainsV1alpha2::ContactSettings
Defines the contact information associated with a
Registration. -
#create_time ⇒ String
Output only.
-
#dns_settings ⇒ Google::Apis::DomainsV1alpha2::DnsSettings
Defines the DNS configuration of a
Registration, including name servers, DNSSEC, and glue records. -
#domain_name ⇒ String
Required.
-
#domain_properties ⇒ Array<String>
Output only.
-
#expire_time ⇒ String
Output only.
-
#issues ⇒ Array<String>
Output only.
-
#labels ⇒ Hash<String,String>
Set of labels associated with the
Registration. -
#management_settings ⇒ Google::Apis::DomainsV1alpha2::ManagementSettings
Defines renewal, billing, and transfer settings for a
Registration. -
#name ⇒ String
Output only.
-
#pending_contact_settings ⇒ Google::Apis::DomainsV1alpha2::ContactSettings
Defines the contact information associated with a
Registration. -
#provider ⇒ String
Output only.
-
#register_failure_reason ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#supported_privacy ⇒ Array<String>
Output only.
-
#transfer_failure_reason ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Registration
constructor
A new instance of Registration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Registration
Returns a new instance of Registration.
1926 1927 1928 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contact_settings ⇒ Google::Apis::DomainsV1alpha2::ContactSettings
Defines the contact information associated with a Registration. ICANN requires all domain names to have associated contact
information. The registrant_contact is considered the domain's legal owner,
and often the other contacts are identical.
Corresponds to the JSON property contactSettings
1838 1839 1840 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1838 def contact_settings @contact_settings end |
#create_time ⇒ String
Output only. The creation timestamp of the Registration resource.
Corresponds to the JSON property createTime
1843 1844 1845 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1843 def create_time @create_time end |
#dns_settings ⇒ Google::Apis::DomainsV1alpha2::DnsSettings
Defines the DNS configuration of a Registration, including name servers,
DNSSEC, and glue records.
Corresponds to the JSON property dnsSettings
1849 1850 1851 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1849 def dns_settings @dns_settings end |
#domain_name ⇒ String
Required. Immutable. The domain name. Unicode domain names must be expressed
in Punycode format.
Corresponds to the JSON property domainName
1855 1856 1857 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1855 def domain_name @domain_name end |
#domain_properties ⇒ Array<String>
Output only. Special properties of the domain.
Corresponds to the JSON property domainProperties
1860 1861 1862 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1860 def domain_properties @domain_properties end |
#expire_time ⇒ String
Output only. The expiration timestamp of the Registration.
Corresponds to the JSON property expireTime
1865 1866 1867 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1865 def expire_time @expire_time end |
#issues ⇒ Array<String>
Output only. The set of issues with the Registration that require attention.
Corresponds to the JSON property issues
1870 1871 1872 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1870 def issues @issues end |
#labels ⇒ Hash<String,String>
Set of labels associated with the Registration.
Corresponds to the JSON property labels
1875 1876 1877 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1875 def labels @labels end |
#management_settings ⇒ Google::Apis::DomainsV1alpha2::ManagementSettings
Defines renewal, billing, and transfer settings for a Registration.
Corresponds to the JSON property managementSettings
1880 1881 1882 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1880 def management_settings @management_settings end |
#name ⇒ String
Output only. Name of the Registration resource, in the format projects/*/
locations/*/registrations/.
Corresponds to the JSON property name
1886 1887 1888 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1886 def name @name end |
#pending_contact_settings ⇒ Google::Apis::DomainsV1alpha2::ContactSettings
Defines the contact information associated with a Registration. ICANN requires all domain names to have associated contact
information. The registrant_contact is considered the domain's legal owner,
and often the other contacts are identical.
Corresponds to the JSON property pendingContactSettings
1894 1895 1896 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1894 def pending_contact_settings @pending_contact_settings end |
#provider ⇒ String
Output only. Current domain management provider.
Corresponds to the JSON property provider
1899 1900 1901 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1899 def provider @provider end |
#register_failure_reason ⇒ String
Output only. The reason the domain registration failed. Only set for domains
in REGISTRATION_FAILED state.
Corresponds to the JSON property registerFailureReason
1905 1906 1907 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1905 def register_failure_reason @register_failure_reason end |
#state ⇒ String
Output only. The state of the Registration
Corresponds to the JSON property state
1910 1911 1912 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1910 def state @state end |
#supported_privacy ⇒ Array<String>
Output only. Set of options for the contact_settings.privacy field that this
Registration supports.
Corresponds to the JSON property supportedPrivacy
1916 1917 1918 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1916 def supported_privacy @supported_privacy end |
#transfer_failure_reason ⇒ String
Output only. Deprecated: For more information, see Cloud Domains feature
deprecation. The reason the domain transfer failed. Only set for domains in
TRANSFER_FAILED state.
Corresponds to the JSON property transferFailureReason
1924 1925 1926 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1924 def transfer_failure_reason @transfer_failure_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1931 def update!(**args) @contact_settings = args[:contact_settings] if args.key?(:contact_settings) @create_time = args[:create_time] if args.key?(:create_time) @dns_settings = args[:dns_settings] if args.key?(:dns_settings) @domain_name = args[:domain_name] if args.key?(:domain_name) @domain_properties = args[:domain_properties] if args.key?(:domain_properties) @expire_time = args[:expire_time] if args.key?(:expire_time) @issues = args[:issues] if args.key?(:issues) @labels = args[:labels] if args.key?(:labels) @management_settings = args[:management_settings] if args.key?(:management_settings) @name = args[:name] if args.key?(:name) @pending_contact_settings = args[:pending_contact_settings] if args.key?(:pending_contact_settings) @provider = args[:provider] if args.key?(:provider) @register_failure_reason = args[:register_failure_reason] if args.key?(:register_failure_reason) @state = args[:state] if args.key?(:state) @supported_privacy = args[:supported_privacy] if args.key?(:supported_privacy) @transfer_failure_reason = args[:transfer_failure_reason] if args.key?(:transfer_failure_reason) end |