Class: Google::Apis::DomainsV1alpha2::Status
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1alpha2::Status
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1alpha2/classes.rb,
lib/google/apis/domains_v1alpha2/representations.rb,
lib/google/apis/domains_v1alpha2/representations.rb
Overview
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
-
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details.
-
#message ⇒ String
A developer-facing error message, which should be in English.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Status
constructor
A new instance of Status.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Status
Returns a new instance of Status.
2253 2254 2255 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
Corresponds to the JSON property code
2238 2239 2240 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2238 def code @code end |
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details. There is a common set of
message types for APIs to use.
Corresponds to the JSON property details
2244 2245 2246 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2244 def details @details end |
#message ⇒ String
A developer-facing error message, which should be in English. Any user-facing
error message should be localized and sent in the google.rpc.Status.details
field, or localized by the client.
Corresponds to the JSON property message
2251 2252 2253 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2251 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2258 2259 2260 2261 2262 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2258 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @message = args[:message] if args.key?(:message) end |