Class: Google::Apis::DomainsV1alpha2::TransferDomainRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1alpha2/classes.rb,
lib/google/apis/domains_v1alpha2/representations.rb,
lib/google/apis/domains_v1alpha2/representations.rb

Overview

Deprecated: For more information, see Cloud Domains feature deprecation. Request for the TransferDomain method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferDomainRequest

Returns a new instance of TransferDomainRequest.



2373
2374
2375
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorization_codeGoogle::Apis::DomainsV1alpha2::AuthorizationCode

Defines an authorization code. Corresponds to the JSON property authorizationCode



2330
2331
2332
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2330

def authorization_code
  @authorization_code
end

#contact_noticesArray<String>

The list of contact notices that you acknowledge. The notices needed here depend on the values specified in registration.contact_settings. Corresponds to the JSON property contactNotices

Returns:

  • (Array<String>)


2336
2337
2338
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2336

def contact_notices
  @contact_notices
end

#registrationGoogle::Apis::DomainsV1alpha2::Registration

The Registration resource facilitates managing and configuring domain name registrations. There are several ways to create a new Registration resource: To create a new Registration resource, find a suitable domain name by calling the SearchDomains method with a query to see available domain name options. After choosing a name, call RetrieveRegisterParameters to ensure availability and obtain information like pricing, which is needed to build a call to RegisterDomain. Another way to create a new Registration is to transfer an existing domain from another registrar (Deprecated: For more information, see Cloud Domains feature deprecation). First, go to the current registrar to unlock the domain for transfer and retrieve the domain's transfer authorization code. Then call RetrieveTransferParameters to confirm that the domain is unlocked and to get values needed to build a call to TransferDomain . Finally, you can create a new Registration by importing an existing domain managed with Google Domains (Deprecated: For more information, see Cloud Domains feature deprecation). First, call RetrieveImportableDomains to list domains to which the calling user has sufficient access. Then call ImportDomain on any domain names you want to use with Cloud Domains. Corresponds to the JSON property registration



2360
2361
2362
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2360

def registration
  @registration
end

#validate_onlyBoolean Also known as: validate_only?

Validate the request without actually transferring the domain. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


2365
2366
2367
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2365

def validate_only
  @validate_only
end

#yearly_priceGoogle::Apis::DomainsV1alpha2::Money

Represents an amount of money with its currency type. Corresponds to the JSON property yearlyPrice



2371
2372
2373
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2371

def yearly_price
  @yearly_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2378
2379
2380
2381
2382
2383
2384
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2378

def update!(**args)
  @authorization_code = args[:authorization_code] if args.key?(:authorization_code)
  @contact_notices = args[:contact_notices] if args.key?(:contact_notices)
  @registration = args[:registration] if args.key?(:registration)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
  @yearly_price = args[:yearly_price] if args.key?(:yearly_price)
end