Class: Google::Apis::DomainsV1alpha2::Registration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1alpha2/classes.rb,
lib/google/apis/domains_v1alpha2/representations.rb,
lib/google/apis/domains_v1alpha2/representations.rb

Overview

The Registration resource facilitates managing and configuring domain name registrations. There are several ways to create a new Registration resource: To create a new Registration resource, find a suitable domain name by calling the SearchDomains method with a query to see available domain name options. After choosing a name, call RetrieveRegisterParameters to ensure availability and obtain information like pricing, which is needed to build a call to RegisterDomain. Another way to create a new Registration is to transfer an existing domain from another registrar (Deprecated: For more information, see Cloud Domains feature deprecation). First, go to the current registrar to unlock the domain for transfer and retrieve the domain's transfer authorization code. Then call RetrieveTransferParameters to confirm that the domain is unlocked and to get values needed to build a call to TransferDomain . Finally, you can create a new Registration by importing an existing domain managed with Google Domains (Deprecated: For more information, see Cloud Domains feature deprecation). First, call RetrieveImportableDomains to list domains to which the calling user has sufficient access. Then call ImportDomain on any domain names you want to use with Cloud Domains.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Registration

Returns a new instance of Registration.



1918
1919
1920
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contact_settingsGoogle::Apis::DomainsV1alpha2::ContactSettings

Defines the contact information associated with a Registration. ICANN requires all domain names to have associated contact information. The registrant_contact is considered the domain's legal owner, and often the other contacts are identical. Corresponds to the JSON property contactSettings



1830
1831
1832
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1830

def contact_settings
  @contact_settings
end

#create_timeString

Output only. The creation timestamp of the Registration resource. Corresponds to the JSON property createTime

Returns:

  • (String)


1835
1836
1837
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1835

def create_time
  @create_time
end

#dns_settingsGoogle::Apis::DomainsV1alpha2::DnsSettings

Defines the DNS configuration of a Registration, including name servers, DNSSEC, and glue records. Corresponds to the JSON property dnsSettings



1841
1842
1843
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1841

def dns_settings
  @dns_settings
end

#domain_nameString

Required. Immutable. The domain name. Unicode domain names must be expressed in Punycode format. Corresponds to the JSON property domainName

Returns:

  • (String)


1847
1848
1849
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1847

def domain_name
  @domain_name
end

#domain_propertiesArray<String>

Output only. Special properties of the domain. Corresponds to the JSON property domainProperties

Returns:

  • (Array<String>)


1852
1853
1854
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1852

def domain_properties
  @domain_properties
end

#expire_timeString

Output only. The expiration timestamp of the Registration. Corresponds to the JSON property expireTime

Returns:

  • (String)


1857
1858
1859
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1857

def expire_time
  @expire_time
end

#issuesArray<String>

Output only. The set of issues with the Registration that require attention. Corresponds to the JSON property issues

Returns:

  • (Array<String>)


1862
1863
1864
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1862

def issues
  @issues
end

#labelsHash<String,String>

Set of labels associated with the Registration. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1867
1868
1869
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1867

def labels
  @labels
end

#management_settingsGoogle::Apis::DomainsV1alpha2::ManagementSettings

Defines renewal, billing, and transfer settings for a Registration. Corresponds to the JSON property managementSettings



1872
1873
1874
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1872

def management_settings
  @management_settings
end

#nameString

Output only. Name of the Registration resource, in the format projects/*/ locations/*/registrations/. Corresponds to the JSON property name

Returns:

  • (String)


1878
1879
1880
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1878

def name
  @name
end

#pending_contact_settingsGoogle::Apis::DomainsV1alpha2::ContactSettings

Defines the contact information associated with a Registration. ICANN requires all domain names to have associated contact information. The registrant_contact is considered the domain's legal owner, and often the other contacts are identical. Corresponds to the JSON property pendingContactSettings



1886
1887
1888
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1886

def pending_contact_settings
  @pending_contact_settings
end

#providerString

Output only. Current domain management provider. Corresponds to the JSON property provider

Returns:

  • (String)


1891
1892
1893
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1891

def provider
  @provider
end

#register_failure_reasonString

Output only. The reason the domain registration failed. Only set for domains in REGISTRATION_FAILED state. Corresponds to the JSON property registerFailureReason

Returns:

  • (String)


1897
1898
1899
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1897

def register_failure_reason
  @register_failure_reason
end

#stateString

Output only. The state of the Registration Corresponds to the JSON property state

Returns:

  • (String)


1902
1903
1904
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1902

def state
  @state
end

#supported_privacyArray<String>

Output only. Set of options for the contact_settings.privacy field that this Registration supports. Corresponds to the JSON property supportedPrivacy

Returns:

  • (Array<String>)


1908
1909
1910
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1908

def supported_privacy
  @supported_privacy
end

#transfer_failure_reasonString

Output only. Deprecated: For more information, see Cloud Domains feature deprecation. The reason the domain transfer failed. Only set for domains in TRANSFER_FAILED state. Corresponds to the JSON property transferFailureReason

Returns:

  • (String)


1916
1917
1918
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1916

def transfer_failure_reason
  @transfer_failure_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1923

def update!(**args)
  @contact_settings = args[:contact_settings] if args.key?(:contact_settings)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dns_settings = args[:dns_settings] if args.key?(:dns_settings)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
  @domain_properties = args[:domain_properties] if args.key?(:domain_properties)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @issues = args[:issues] if args.key?(:issues)
  @labels = args[:labels] if args.key?(:labels)
  @management_settings = args[:management_settings] if args.key?(:management_settings)
  @name = args[:name] if args.key?(:name)
  @pending_contact_settings = args[:pending_contact_settings] if args.key?(:pending_contact_settings)
  @provider = args[:provider] if args.key?(:provider)
  @register_failure_reason = args[:register_failure_reason] if args.key?(:register_failure_reason)
  @state = args[:state] if args.key?(:state)
  @supported_privacy = args[:supported_privacy] if args.key?(:supported_privacy)
  @transfer_failure_reason = args[:transfer_failure_reason] if args.key?(:transfer_failure_reason)
end