Class: Google::Apis::DomainsV1alpha2::ResourceRecordSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1alpha2/classes.rb,
lib/google/apis/domains_v1alpha2/representations.rb,
lib/google/apis/domains_v1alpha2/representations.rb

Overview

A unit of data that is returned by the DNS servers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceRecordSet

Returns a new instance of ResourceRecordSet.



2014
2015
2016
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

For example, www.example.com. Corresponds to the JSON property name

Returns:

  • (String)


1983
1984
1985
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1983

def name
  @name
end

#routing_policyGoogle::Apis::DomainsV1alpha2::RrSetRoutingPolicy

A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection. Corresponds to the JSON property routingPolicy



1990
1991
1992
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1990

def routing_policy
  @routing_policy
end

#rrdataArray<String>

As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see examples. Corresponds to the JSON property rrdata

Returns:

  • (Array<String>)


1996
1997
1998
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 1996

def rrdata
  @rrdata
end

#signature_rrdataArray<String>

As defined in RFC 4034 (section 3.2). Corresponds to the JSON property signatureRrdata

Returns:

  • (Array<String>)


2001
2002
2003
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2001

def signature_rrdata
  @signature_rrdata
end

#ttlFixnum

Number of seconds that this ResourceRecordSet can be cached by resolvers. Corresponds to the JSON property ttl

Returns:

  • (Fixnum)


2006
2007
2008
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2006

def ttl
  @ttl
end

#typeString

The identifier of a supported record type. See the list of Supported DNS record types. Corresponds to the JSON property type

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2012

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2019
2020
2021
2022
2023
2024
2025
2026
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2019

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @routing_policy = args[:routing_policy] if args.key?(:routing_policy)
  @rrdata = args[:rrdata] if args.key?(:rrdata)
  @signature_rrdata = args[:signature_rrdata] if args.key?(:signature_rrdata)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
end