Class: Google::Apis::DomainsV1alpha2::TransferDomainRequest
- Inherits:
-
Object
- Object
- Google::Apis::DomainsV1alpha2::TransferDomainRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/domains_v1alpha2/classes.rb,
lib/google/apis/domains_v1alpha2/representations.rb,
lib/google/apis/domains_v1alpha2/representations.rb
Overview
Deprecated: For more information, see Cloud Domains feature deprecation.
Request for the TransferDomain method.
Instance Attribute Summary collapse
-
#authorization_code ⇒ Google::Apis::DomainsV1alpha2::AuthorizationCode
Defines an authorization code.
-
#contact_notices ⇒ Array<String>
The list of contact notices that you acknowledge.
-
#registration ⇒ Google::Apis::DomainsV1alpha2::Registration
The
Registrationresource facilitates managing and configuring domain name registrations. -
#validate_only ⇒ Boolean
(also: #validate_only?)
Validate the request without actually transferring the domain.
-
#yearly_price ⇒ Google::Apis::DomainsV1alpha2::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransferDomainRequest
constructor
A new instance of TransferDomainRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransferDomainRequest
Returns a new instance of TransferDomainRequest.
2357 2358 2359 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorization_code ⇒ Google::Apis::DomainsV1alpha2::AuthorizationCode
Defines an authorization code.
Corresponds to the JSON property authorizationCode
2314 2315 2316 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2314 def @authorization_code end |
#contact_notices ⇒ Array<String>
The list of contact notices that you acknowledge. The notices needed here
depend on the values specified in registration.contact_settings.
Corresponds to the JSON property contactNotices
2320 2321 2322 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2320 def contact_notices @contact_notices end |
#registration ⇒ Google::Apis::DomainsV1alpha2::Registration
The Registration resource facilitates managing and configuring domain name
registrations. There are several ways to create a new Registration resource:
To create a new Registration resource, find a suitable domain name by
calling the SearchDomains method with a query to see available domain name
options. After choosing a name, call RetrieveRegisterParameters to ensure
availability and obtain information like pricing, which is needed to build a
call to RegisterDomain. Another way to create a new Registration is to
transfer an existing domain from another registrar (Deprecated: For more
information, see Cloud Domains feature deprecation). First, go to the current
registrar to unlock the domain for transfer and retrieve the domain's transfer
authorization code. Then call RetrieveTransferParameters to confirm that the
domain is unlocked and to get values needed to build a call to TransferDomain
. Finally, you can create a new Registration by importing an existing domain
managed with Google Domains (Deprecated: For more
information, see Cloud Domains feature deprecation). First, call
RetrieveImportableDomains to list domains to which the calling user has
sufficient access. Then call ImportDomain on any domain names you want to
use with Cloud Domains.
Corresponds to the JSON property registration
2344 2345 2346 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2344 def registration @registration end |
#validate_only ⇒ Boolean Also known as: validate_only?
Validate the request without actually transferring the domain.
Corresponds to the JSON property validateOnly
2349 2350 2351 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2349 def validate_only @validate_only end |
#yearly_price ⇒ Google::Apis::DomainsV1alpha2::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property yearlyPrice
2355 2356 2357 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2355 def yearly_price @yearly_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2362 2363 2364 2365 2366 2367 2368 |
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2362 def update!(**args) @authorization_code = args[:authorization_code] if args.key?(:authorization_code) @contact_notices = args[:contact_notices] if args.key?(:contact_notices) @registration = args[:registration] if args.key?(:registration) @validate_only = args[:validate_only] if args.key?(:validate_only) @yearly_price = args[:yearly_price] if args.key?(:yearly_price) end |