Class: Google::Apis::DomainsV1alpha2::TransferParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1alpha2/classes.rb,
lib/google/apis/domains_v1alpha2/representations.rb,
lib/google/apis/domains_v1alpha2/representations.rb

Overview

Deprecated: For more information, see Cloud Domains feature deprecation. Parameters required to transfer a domain from another registrar.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferParameters

Returns a new instance of TransferParameters.



2422
2423
2424
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_registrarString

The registrar that currently manages the domain. Corresponds to the JSON property currentRegistrar

Returns:

  • (String)


2388
2389
2390
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2388

def current_registrar
  @current_registrar
end

#current_registrar_uriString

The URL of the registrar that currently manages the domain. Corresponds to the JSON property currentRegistrarUri

Returns:

  • (String)


2393
2394
2395
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2393

def current_registrar_uri
  @current_registrar_uri
end

#domain_nameString

The domain name. Unicode domain names are expressed in Punycode format. Corresponds to the JSON property domainName

Returns:

  • (String)


2398
2399
2400
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2398

def domain_name
  @domain_name
end

#name_serversArray<String>

The name servers that currently store the configuration of the domain. Corresponds to the JSON property nameServers

Returns:

  • (Array<String>)


2403
2404
2405
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2403

def name_servers
  @name_servers
end

#supported_privacyArray<String>

Contact privacy options that the domain supports. Corresponds to the JSON property supportedPrivacy

Returns:

  • (Array<String>)


2408
2409
2410
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2408

def supported_privacy
  @supported_privacy
end

#transfer_lock_stateString

Indicates whether the domain is protected by a transfer lock. For a transfer to succeed, this must show UNLOCKED. To unlock a domain, go to its current registrar. Corresponds to the JSON property transferLockState

Returns:

  • (String)


2415
2416
2417
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2415

def transfer_lock_state
  @transfer_lock_state
end

#yearly_priceGoogle::Apis::DomainsV1alpha2::Money

Represents an amount of money with its currency type. Corresponds to the JSON property yearlyPrice



2420
2421
2422
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2420

def yearly_price
  @yearly_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2427
2428
2429
2430
2431
2432
2433
2434
2435
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2427

def update!(**args)
  @current_registrar = args[:current_registrar] if args.key?(:current_registrar)
  @current_registrar_uri = args[:current_registrar_uri] if args.key?(:current_registrar_uri)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
  @name_servers = args[:name_servers] if args.key?(:name_servers)
  @supported_privacy = args[:supported_privacy] if args.key?(:supported_privacy)
  @transfer_lock_state = args[:transfer_lock_state] if args.key?(:transfer_lock_state)
  @yearly_price = args[:yearly_price] if args.key?(:yearly_price)
end