Class: Google::Apis::DomainsV1alpha2::WrrPolicyItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/domains_v1alpha2/classes.rb,
lib/google/apis/domains_v1alpha2/representations.rb,
lib/google/apis/domains_v1alpha2/representations.rb

Overview

A routing block which contains the routing information for one WRR item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WrrPolicyItem

Returns a new instance of WrrPolicyItem.



2489
2490
2491
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_checked_targetsGoogle::Apis::DomainsV1alpha2::HealthCheckTargets

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both. Corresponds to the JSON property healthCheckedTargets



2467
2468
2469
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2467

def health_checked_targets
  @health_checked_targets
end

#rrdataArray<String>

Corresponds to the JSON property rrdata

Returns:

  • (Array<String>)


2472
2473
2474
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2472

def rrdata
  @rrdata
end

#signature_rrdataArray<String>

DNSSEC generated signatures for all the rrdata within this item. When using health-checked targets for DNSSEC-enabled zones, you can only use at most one health-checked IP address per item. Corresponds to the JSON property signatureRrdata

Returns:

  • (Array<String>)


2479
2480
2481
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2479

def signature_rrdata
  @signature_rrdata
end

#weightFloat

The weight corresponding to this WrrPolicyItem object. When multiple WrrPolicyItem objects are configured, the probability of returning an WrrPolicyItem object's data is proportional to its weight relative to the sum of weights configured for all items. This weight must be non-negative. Corresponds to the JSON property weight

Returns:

  • (Float)


2487
2488
2489
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2487

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2494
2495
2496
2497
2498
2499
# File 'lib/google/apis/domains_v1alpha2/classes.rb', line 2494

def update!(**args)
  @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets)
  @rrdata = args[:rrdata] if args.key?(:rrdata)
  @signature_rrdata = args[:signature_rrdata] if args.key?(:signature_rrdata)
  @weight = args[:weight] if args.key?(:weight)
end